<?php
namespace App\Exports;

use App\Models\Work_order;
use Carbon\Carbon;
use Maatwebsite\Excel\Concerns\FromQuery;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\WithMapping;
use Illuminate\Http\Request;

class WorkOrdersExport implements FromQuery, WithHeadings, WithMapping
{
    protected $request;

    public function __construct(Request $request)
    {
        $this->request = $request;
    }

    public function query()
    {
        $query = Work_order::query();

        if ($this->request->get('from') !== null) {
            $query->whereDate('receive_date', '>=', $this->request->input('from'));
        }

        if ($this->request->get('to') !== null) {
            $query->whereDate('receive_date', '<=', $this->request->input('to'));
        }

        if ($this->request->get('company') !== null) {
            $query->where('company_id', $this->request->input('company'));
        }

        if ($this->request->get('client') !== null) {
            $query->where('client_id', $this->request->input('client'));
        }

        if ($this->request->get('contractor') !== null) {
            $query->where('contractor', $this->request->input('contractor'));
        }

        if ($this->request->get('seller') !== null) {
            $query->where('seller', $this->request->input('seller'));
        }

        if ($this->request->get('work_type') !== null) {
            $query->where('work_type', $this->request->input('work_type'));
        }

        if ($this->request->get('processor') !== null) {
            $query->where('processor', $this->request->input('processor'));
        }

        if ($this->request->get('city') !== null) {
            $query->where('city', $this->request->input('city'));
        }

        if ($this->request->get('state') !== null) {
            $query->where('state', $this->request->input('state'));
        }

        if ($this->request->get('zip') !== null) {
            $query->where('zip', $this->request->input('zip'));
        }

        if ($this->request->get('ppw_id') !== null) {
            $query->where('ppw_id', $this->request->input('ppw_id'));
        }

        if ($this->request->get('invoice_from') !== null) {
            $query->whereDate('invoice_date', '>=', $this->request->input('invoice_from'));
        }

        if ($this->request->get('invoice_to') !== null) {
            $query->whereDate('invoice_date', '<=', $this->request->input('invoice_to'));
        }

        if ($this->request->get('work_order_code') !== null) {
            $query->where('work_order_code', 'LIKE', '%' . $this->request->input('work_order_code') . '%');
        }

        return $query->orderBy('id','desc');
    }

    public function map($workOrder): array
    {
        // Calculations and relational data retrieval
        $totalCashIn = $workOrder->bankStatement->where('ppw_amount', '>', 0)->where('account_type', 'Debit')->sum('ppw_amount');
        $totalCashOutFromDebit = abs($workOrder->bankStatement->where('ppw_amount', '<', 0)->where('account_type', 'Debit')->sum('ppw_amount'));
        $totalCashOutFromCredit = abs($workOrder->bankStatement->where('account_type', 'Credit')->sum('ppw_amount'));
        $profit = $totalCashIn - ($totalCashOutFromDebit + $totalCashOutFromCredit);
        $loanAmount = 0; // If there's a loan field, include its calculation here.
        $vendorGotPaid = $totalCashOutFromDebit + $totalCashOutFromCredit + $loanAmount;
        $vendorUnpaid = $workOrder->vendor_amount - $vendorGotPaid;
        $grossProfit = $workOrder->client_amount - $workOrder->vendor_amount;
        $receivedGP = $totalCashIn - $workOrder->vendor_amount;

        return [
            $workOrder->ppw_id,
            $workOrder->work_order_code,
            optional($workOrder->companyDetails)->name ?? 'N/A',
            optional($workOrder->clientDetails)->name ?? 'N/A',
            $workOrder->main_order_ppw,
            $workOrder->receive_date ? Carbon::parse($workOrder->receive_date)->format('m/d/Y') : 'N/A',
            $workOrder->contractor,
            $workOrder->work_type,
            $workOrder->city,
            $workOrder->state,
            $workOrder->zip,
            $workOrder->processor,
            $workOrder->invoice_date ? Carbon::parse($workOrder->invoice_date)->format('m/d/Y') : 'N/A',
            $workOrder->seller,
            $workOrder->source_ppw,
            $workOrder->client_amount,
            $totalCashIn,
            $workOrder->client_amount - $totalCashIn,
            $totalCashOutFromDebit,
            $totalCashOutFromCredit,
            $workOrder->vendor_amount,
            $vendorGotPaid,
            $vendorUnpaid,
            $grossProfit,
            $receivedGP,
        ];
    }

    public function headings(): array
    {
        return [
            'PPW ID',
            'Work Order Code',
            'Company',
            'Client',
            'Main order PPW',
            'Receive Date',
            'Contractor',
            'Work Type',
            'City',
            'State',
            'Zip',
            'Processor',
            'Invoice Date',
            'Seller',
            'Source PPW',
            'Client Amount',
            'Total Cash In',
            'Client Unpaid',
            'Total Cash Out (Debit)',
            'Total Cash Out (Credit)',
            'Vendor Amount',
            'Vendor Paid',
            'Vendor Unpaid',
            'Gross Profit',
            'Received GP',
        ];
    }
}
