<?php

namespace App\Http\Controllers;

use App\Imports\EmployeeImport;
use App\Models\Employee;
use Illuminate\Http\Request;
use Maatwebsite\Excel\Facades\Excel;

class EmployeeController extends Controller
{
    public function __construct(){
        $this->middleware('RedirectIfNotAuthenticate');
    }

    public function index(Request $request){
        // Start with the Employee model and apply conditional filters
        $query = Employee::query();

        // Apply filtering based on user input
        if ($request->filled('class')) {
            $query->where('class', $request->class);
        }

        if ($request->filled('state')) {
            $query->where('state', $request->state);
        }

        if ($request->filled('zip')) {
            $query->where('zip', $request->zip);
        }

        if ($request->filled('rate_type')) {
            $query->where('rate_type', $request->rate_type);
        }
        if ($request->filled('dependant')) {
            $query->where('dependant', $request->dependant);
        }

        if ($request->filled('apt')) {
            $query->where('apt', 'like', '%' . $request->apt . '%');  // Allow partial matches for APT
        }

        // Get the filtered employees, paginated
        $employees = $query->paginate(10);

        // Pass additional data (like dropdown lists for class, state, etc.) if needed
        $classes = Employee::distinct()->pluck('class', 'class');
        $states = Employee::distinct()->pluck('state', 'state');
        $zip_codes = Employee::distinct()->pluck('zip', 'zip');
        $rate_types = Employee::distinct()->pluck('rate_type', 'rate_type');
        $dependants = Employee::distinct()->pluck('dependant', 'dependant');

        // Return the view with the data and filters
        return view('admin.modules.employee.index', compact('employees', 'classes', 'states', 'zip_codes', 'rate_types', 'dependants'));
    }

    public function create(){
        return view('admin.modules.employee.import');
    }

    public function edit($id){
        $employee = Employee::find($id);
        return view('admin.modules.employee.edit', compact('employee'));
    }

    public function store(Request $request){
        request()->validate([
            'employee_file' => 'required|mimes:xlsx|max:2048'
        ]);
        $import = new EmployeeImport();
        Excel::import($import, $request->file('employee_file'));
        $results = $import->getResults();
        session()->flash('import_status', [
            'message' => "{$results['success_count']}/" . ($results['success_count'] + $results['failure_count']) . " rows has been inserted/updated.",
            'errors' => $results['errors']
        ]);

        return redirect()->back();
    }
    public function update(Request $request, $id)
    {
        // Validate incoming request data
        $validatedData = $request->validate([
            'first_name' => 'required|string|max:50',
            'last_name' => 'required|string|max:50',
            'dob' => 'nullable|date',
            'class' => 'nullable|string|max:50',
            'address' => 'nullable|string|max:100',
            'city' => 'nullable|string|max:50',
            'state' => 'nullable|string|max:50',
            'zip' => 'nullable|string|max:10',
            'dependant' => 'nullable|string|max:50',
            'apt' => 'nullable|string|max:50',
            'rate_type' => 'nullable|in:BL,PCC,79',
            'regular_rate' => 'nullable|numeric',
            'benefit_rate' => 'nullable|numeric',
        ]);

        // Find the employee by ID
        $employee = Employee::findOrFail($id);

        // Update employee details with validated data
        $employee->update($validatedData);

        // Redirect to a specific page (e.g., employee list or detail page)
        return redirect()->to('module/employee')->with('success', 'Employee updated successfully.');
    }
}
