<?php

// app/Http/Controllers/ExpenseHeadController.php
namespace App\Http\Controllers;

use App\Models\ExpenseHead;
use Illuminate\Http\Request;

class ExpenseHeadController extends Controller
{
    public function index()
    {
        $expenseHeads = ExpenseHead::with('parent')->orderBy('id','desc')->get();
        return view('admin.modules.expense_heads.index', compact('expenseHeads'));
    }

    public function create()
    {
        $parents = ExpenseHead::whereNull('parent_id')->get();
        return view('admin.modules.expense_heads.create', compact('parents'));
    }

    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'parent_id' => 'nullable|exists:expense_heads,id',
        ]);

        ExpenseHead::create($request->only('name', 'parent_id'));

        return redirect()->to('module/expense_head')->with('success', 'Expense Head created successfully.');
    }

    public function edit($id)
    {
        $expenseHead = ExpenseHead::findOrFail($id);
        $parents = ExpenseHead::whereNull('parent_id')->where('id', '!=', $id)->get();
        return view('admin.modules.expense_heads.edit', compact('expenseHead', 'parents'));
    }

    public function update(Request $request, $id)
    {
        //return $request->all();
        $request->validate([
            'name' => 'required|string|max:255',
            'parent_id' => 'nullable|exists:expense_heads,id',
        ]);

        $expenseHead = ExpenseHead::findOrFail($id);
        $expenseHead->update($request->only('name', 'parent_id'));

        return redirect()->to('module/expense_head')->with('success', 'Expense Head updated successfully.');
    }
}
