<?php

namespace App\Http\Controllers;

use App\Models\Bank_statement;
use App\Models\Company;
use App\Models\ExpenseHead;
use App\Models\Work_order;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;

class ReportController extends Controller
{
    public function __construct(){
        $this->middleware('RedirectIfNotAuthenticate');
    }

    public function companyWiseReport(Request $request){
        $company_id = Company::first()->id;
        if ($request->has('company')) {
            $company_id = $request->company;
        }

        $company_wise_clients = Work_order::where('company_id', $company_id)->groupBy('client_id')->get();
        $results = [];

        // Initialize totals
        $total_work_orders = 0;
        $total_client_total = 0;
        $total_client_paid = 0;
        $total_client_unpaid = 0;
        $total_cashout_from_bank = 0;
        $total_cashout_from_credit = 0;
        $total_cashout_from_loan = 0;
        $total_vendor_total = 0;
        $total_vendor_paid = 0;
        $total_vendor_unpaid = 0;
        $total_gross_profit = 0;
        $total_receive_gp = 0;

        foreach ($company_wise_clients as $client) {
            $ppw_ids = Work_order::where('company_id', $company_id)->where('client_id', $client->client_id)->pluck('ppw_id');
            $client_total = Work_order::where(['company_id' => $company_id, 'client_id' => $client->client_id])->sum('client_amount');
            $client_paid = Bank_statement::whereIn('ppw_id', $ppw_ids)->where('ppw_amount', '>', 0)->where('account_type', 'Debit')->sum('ppw_amount');
            $client_unpaid = $client_total - $client_paid;
            $total_cashout_debit = abs(Bank_statement::whereIn('ppw_id', $ppw_ids)->where('ppw_amount', '<', 0)->where('account_type', 'Debit')->sum('ppw_amount'));
            $total_cashout_credit = abs(Bank_statement::whereIn('ppw_id', $ppw_ids)->where('account_type', 'Credit')->sum('ppw_amount'));
            $total_cashout_loan = 0; // Assuming you get this value from elsewhere if needed
            $vendor_total = Work_order::where(['company_id' => $company_id, 'client_id' => $client->client_id])->sum('vendor_amount');
            $vendor_paid = $total_cashout_debit + $total_cashout_credit + $total_cashout_loan;
            $vendor_unpaid = $vendor_total - $vendor_paid;

            $results[$client->clientDetails->name] = [
                'work_orders' => Work_order::where('company_id', $company_id)->where('client_id', $client->client_id)->count(),
                'client_total' => $client_total,
                'client_paid' => $client_paid,
                'client_unpaid' => $client_unpaid,
                'cashout_from_bank' => $total_cashout_debit,
                'cashout_from_credit' => $total_cashout_credit,
                'cashout_from_loan' => $total_cashout_loan,
                'vendor_total' => $vendor_total,
                'vendor_paid' => $vendor_paid,
                'vendor_unpaid' => $vendor_unpaid,
                'gross_profit' => $client_total - $vendor_total,
                'receive_gp' => $client_paid - $vendor_total,
            ];

            // Aggregate totals
            $total_work_orders += $results[$client->clientDetails->name]['work_orders'];
            $total_client_total += $results[$client->clientDetails->name]['client_total'];
            $total_client_paid += $results[$client->clientDetails->name]['client_paid'];
            $total_client_unpaid += $results[$client->clientDetails->name]['client_unpaid'];
            $total_cashout_from_bank += $results[$client->clientDetails->name]['cashout_from_bank'];
            $total_cashout_from_credit += $results[$client->clientDetails->name]['cashout_from_credit'];
            $total_cashout_from_loan += $results[$client->clientDetails->name]['cashout_from_loan'];
            $total_vendor_total += $results[$client->clientDetails->name]['vendor_total'];
            $total_vendor_paid += $results[$client->clientDetails->name]['vendor_paid'];
            $total_vendor_unpaid += $results[$client->clientDetails->name]['vendor_unpaid'];
            $total_gross_profit += $results[$client->clientDetails->name]['gross_profit'];
            $total_receive_gp += $results[$client->clientDetails->name]['receive_gp'];
        }

        $company_lists = Company::pluck('name', 'id');

        return view('admin.modules.reports.company_wise_report', compact(
            'results',
            'company_lists',
            'total_work_orders',
            'total_client_total',
            'total_client_paid',
            'total_client_unpaid',
            'total_cashout_from_bank',
            'total_cashout_from_credit',
            'total_cashout_from_loan',
            'total_vendor_total',
            'total_vendor_paid',
            'total_vendor_unpaid',
            'total_gross_profit',
            'total_receive_gp'
        ));
    }
    public function expense_report(Request $request){
        $expense_heads = ExpenseHead::where('parent_id',null)->pluck('name','id');
        if($request->has('expense_id')){
            $sub_head_ids = ExpenseHead::where('parent_id',  $request->expense_id)->pluck('id')->toArray();
        }else{
            $sub_head_ids = ExpenseHead::where('parent_id',  '!=', null)->pluck('id')->toArray();
        }
        $results = Bank_statement::whereIn('expense_id',$sub_head_ids)->paginate(20);
        //return $results;
        return view('admin.modules.reports.expense', compact('expense_heads', 'results'));
    }
}
