<?php

namespace App\Http\Controllers;


use App\Imports\WorkOrderImport;
use App\Models\Bank_statement;
use App\Models\Client;
use App\Models\Company;
use App\Models\Work_order;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;
use Maatwebsite\Excel\Facades\Excel;

class WorkOrderController extends Controller
{
    public function __construct(){
        $this->middleware('RedirectIfNotAuthenticate');
    }
    public function index(){
        $results = Work_order::with('subOrder')->orderBy('id','desc')->where('main_order_ppw', 0)->paginate(100);
        $results->each(function($item){
            $ppw_id_including_sub_orders = $item->subOrder->pluck('ppw_id')->toArray();
            $ppw_id_including_sub_orders[] = $item->ppw_id;
            $item->client_total = $item->client_amount + $item->subOrder()->sum('client_amount');
            $row_of_client_paid = Bank_statement::whereIn('ppw_id', $ppw_id_including_sub_orders)->where('ppw_amount', '>', 0)->where('account_type', 'Debit');
            if($row_of_client_paid->count() > 0){
                $item->total_cash_in = $row_of_client_paid->sum('ppw_amount');
            }
            $item->client_unpaid = $item->client_total - $item->total_cash_in;
            $item->total_cash_out_from_debit = abs(Bank_statement::whereIn('ppw_id', $ppw_id_including_sub_orders)->where('ppw_amount', '<', 0)->where('account_type', 'Debit')->sum('ppw_amount'));
            $item->total_cash_out_from_credit = abs(Bank_statement::whereIn('ppw_id', $ppw_id_including_sub_orders)->where('account_type', 'Credit')->sum('ppw_amount'));
            $item->profit = $item->total_cash_in -  ($item->total_cash_out_from_debit+$item->total_cash_out_from_credit);
            $loan_amount = 0;
            $item->loan_amount = $loan_amount;
            $vendor_total_of_sub_order =  Work_order::where('main_order_ppw', $item->ppw_id)->sum('vendor_amount');
            $vendor_total = $item->vendor_amount + $vendor_total_of_sub_order;
            $paid_to_vendor = ($item->total_cash_out_from_debit + $item->total_cash_out_from_credit+ $loan_amount);
            $item->vendor_total = $vendor_total;
            $item->vendor_got_paid = $paid_to_vendor;
            $item->vendor_unpaid = $vendor_total - $paid_to_vendor;
            $item->gross_profit = $item->client_amount - $paid_to_vendor;
            if($row_of_client_paid->count() > 0){
                $receive_gp = $item->total_cash_in - $vendor_total;
                $item->received_gp = $receive_gp;
            }

        });

        // Summary Row;
        $client_total = Work_order::sum('client_amount');
        $vendor_total = Work_order::sum('vendor_amount');
        $client_paid = Bank_statement::where('ppw_id', '!=', null)->where('ppw_amount', '>', 0)->where('account_type', 'Debit')->sum('ppw_amount');
        $client_unpaid = $client_total - $client_paid;
        $total_cashout_debit = abs(Bank_statement::where('ppw_id', '!=', null)->where('ppw_amount', '<', 0)->where('account_type', 'Debit')->sum('ppw_amount'));
        $total_cashout_credit = abs(Bank_statement::where('ppw_id', '!=', null)->where('account_type', 'Credit')->sum('ppw_amount'));
        $total_cashout_loan = 0; // Assuming you get this value from elsewhere if needed
        $vendor_paid = $total_cashout_debit + $total_cashout_credit + $total_cashout_loan;
        $vendor_unpaid = $vendor_total - $vendor_paid;
        $summary_row = [
            'client_total'=>$client_total,
            'client_paid' => $client_paid,
            'client_unpaid' => $client_unpaid,
            'paid_from_debit' => $total_cashout_debit,
            'paid_from_credit' => $total_cashout_credit,
            'paid_from_loan' => $total_cashout_loan,
            'vendor_total' => $vendor_total,
            'vendor_paid' => $vendor_paid,
            'vendor_unpaid' => $vendor_unpaid,
            'gross_profit' => $client_total - $vendor_paid,
            'receive_gp' => $client_paid - $vendor_total,
        ];


        $contractors = Work_order::where('contractor','!=', null)->groupBy('contractor')->pluck('contractor','contractor');
        $seller = Work_order::where('seller','!=', null)->groupBy('seller')->pluck('seller','seller');
        $work_type = Work_order::where('work_type','!=', null)->groupBy('work_type')->pluck('work_type','work_type');
        $processor = Work_order::where('processor','!=', null)->groupBy('processor')->pluck('processor','processor');
        $cities = Work_order::where('city','!=', null)->groupBy('city')->pluck('city','city');
        $states = Work_order::where('state','!=', null)->groupBy('state')->pluck('state','state');
        $zip_codes = Work_order::where('zip','!=', null)->groupBy('zip')->pluck('zip','zip');
        $clients = Client::pluck('name','id');
        $companies = Company::pluck('name','id');


        return view('admin.modules.work_order.index', compact(
            'results',
            'contractors',
            'seller',
            'work_type',
            'processor',
            'cities',
            'states',
            'zip_codes',
            'clients',
            'companies',
            'summary_row'
        ));
    }
    public function create(){
        return view('admin.modules.work_order.import');
    }
    public function store(Request $request){
        request()->validate([
            'work_order_file' => 'required|mimes:xlsx|max:2048'
        ]);
        $import = new WorkOrderImport;
        Excel::import($import, $request->file('work_order_file'));

        $results = $import->getResults();
        session()->flash('import_status', [
            'message' => "{$results['success_count']}/" . ($results['success_count'] + $results['failure_count']) . " rows imported successfully.",
            'errors' => $results['errors']
        ]);

        return redirect()->back();
    }
//    public function search(Request $request){
//        $query = Work_order::query();
//        if ($request->get('from') !== null) {
//            $query->whereDate('receive_date', '>=', $request->input('from'));
//        }
//        if ($request->get('to') !== null) {
//            $query->whereDate('receive_date', '<=', $request->input('to'));
//        }
//
//        // Apply other filters
//        if ($request->get('company') !== null) {
//            $query->where('company_id', $request->input('company'));
//        }
//        if ($request->get('client') !== null) {
//            $query->where('client_id', $request->input('client'));
//        }
//        if ($request->get('contractor') !== null) {
//            $query->where('contractor', $request->input('contractor'));
//        }
//        if ($request->get('seller') !== null) {
//            $query->where('seller', $request->input('seller'));
//        }
//        if ($request->get('work_type') !== null) {
//            $query->where('work_type', $request->input('work_type'));
//        }
//        if ($request->get('processor') !== null) {
//            $query->where('processor', $request->input('processor'));
//        }
//        if ($request->get('city') !== null) {
//            $query->where('city', $request->input('city'));
//        }
//        if ($request->get('state') !== null) {
//            $query->where('state', $request->input('state'));
//        }
//        if ($request->get('zip') !== null) {
//            $query->where('zip', $request->input('zip'));
//        }
//
//        if ($request->get('invoice_from') !== null) {
//            $query->whereDate('invoice_date', '>=', $request->input('invoice_from'));
//        }
//        if ($request->get('invoice_to') !== null) {
//            $query->whereDate('invoice_date', '<=', $request->input('invoice_to'));
//        }
//
//        if ($request->get('ppw_id') !== null || $request->get('work_order_code') !== null) {
//            $subQuery = Work_order::query();
//
//            if ($request->get('ppw_id') !== null) {
//                $subQuery->where('ppw_id', $request->input('ppw_id'));
//            }
//            if ($request->get('work_order_code') !== null) {
//                $subQuery->where('work_order_code', 'LIKE', '%' . $request->input('work_order_code') . '%');
//            }
//
//            $mainOrders = $subQuery->where('main_order_ppw', 0)->pluck('id')->toArray();
//            $subOrders = $subQuery->where('main_order_ppw', '!=', 0)->pluck('id')->toArray();
//
//            $query->whereIn('id', array_merge($mainOrders, $subOrders));
//        }
//
//
//        // Summary Row;
//        $client_total = $query->sum('client_amount');
//        //Log::info($query->where('main_order_ppw','!=', 0)->pluck('ppw_id'));
//        $vendor_total = $query->sum('vendor_amount');
//        $client_paid = Bank_statement::where('ppw_id', '!=', null)->where('ppw_amount', '>', 0)->where('account_type', 'Debit')->sum('ppw_amount');
//        $client_unpaid = $client_total - $client_paid;
//        $total_cashout_debit = abs(Bank_statement::where('ppw_id', '!=', null)->where('ppw_amount', '<', 0)->where('account_type', 'Debit')->sum('ppw_amount'));
//        $total_cashout_credit = abs(Bank_statement::where('ppw_id', '!=', null)->where('account_type', 'Credit')->sum('ppw_amount'));
//        $total_cashout_loan = 0; // Assuming you get this value from elsewhere if needed
//        $vendor_paid = $total_cashout_debit + $total_cashout_credit + $total_cashout_loan;
//        $vendor_unpaid = $vendor_total - $vendor_paid;
//        $summary_row = [
//            'client_total'=>$client_total,
//            'client_paid' => $client_paid,
//            'client_unpaid' => $client_unpaid,
//            'paid_from_debit' => $total_cashout_debit,
//            'paid_from_credit' => $total_cashout_credit,
//            'paid_from_loan' => $total_cashout_loan,
//            'vendor_total' => $vendor_total,
//            'vendor_paid' => $vendor_paid,
//            'vendor_unpaid' => $vendor_unpaid,
//            'gross_profit' => $client_total - $vendor_paid,
//            'receive_gp' => $client_paid - $vendor_total,
//        ];
//
//        $results = $query->orderBy('id','desc')->where('main_order_ppw', 0)->paginate(100);
//        $results->each(function($item) use(&$summary_row){
//            $ppw_id_including_sub_orders = $item->subOrder->pluck('ppw_id')->toArray();
//            $ppw_id_including_sub_orders[] = $item->ppw_id;
//            $item->client_total = $item->client_amount + $item->subOrder()->sum('client_amount');
//            $row_of_client_paid = Bank_statement::whereIn('ppw_id', $ppw_id_including_sub_orders)->where('ppw_amount', '>', 0)->where('account_type', 'Debit');
//            if($row_of_client_paid->count() > 0){
//                $item->total_cash_in = $row_of_client_paid->sum('ppw_amount');
//            }
//            $item->client_unpaid = $item->client_amount - $item->total_cash_in;
//            $item->total_cash_out_from_debit = abs(Bank_statement::whereIn('ppw_id', $ppw_id_including_sub_orders)->where('ppw_amount', '<', 0)->where('account_type', 'Debit')->sum('ppw_amount'));
//            $item->total_cash_out_from_credit = abs(Bank_statement::whereIn('ppw_id', $ppw_id_including_sub_orders)->where('account_type', 'Credit')->sum('ppw_amount'));
//            $item->profit = $item->total_cash_in -  ($item->total_cash_out_from_debit+$item->total_cash_out_from_credit);
//            $loan_amount = 0;
//            $item->loan_amount = $loan_amount;
//            $vendor_total_of_sub_order =  Work_order::where('main_order_ppw', $item->ppw_id)->sum('vendor_amount');
//            $vendor_total = $item->vendor_amount + $vendor_total_of_sub_order;
//            $paid_to_vendor = ($item->total_cash_out_from_debit + $item->total_cash_out_from_credit+ $loan_amount);
//            $item->vendor_total = $vendor_total;
//            $item->vendor_got_paid = $paid_to_vendor;
//            $item->vendor_unpaid = $vendor_total - $paid_to_vendor;
//            $item->gross_profit = $item->client_amount - $paid_to_vendor;
//            if($row_of_client_paid->count() > 0){
//                $receive_gp = $item->total_cash_in - $vendor_total;
//                $item->received_gp =$receive_gp;
//            }
//        });
//
//        $contractors = Work_order::where('contractor','!=', null)->groupBy('contractor')->pluck('contractor','contractor');
//        $seller = Work_order::where('seller','!=', null)->groupBy('seller')->pluck('seller','seller');
//        $work_type = Work_order::where('work_type','!=', null)->groupBy('work_type')->pluck('work_type','work_type');
//        $processor = Work_order::where('processor','!=', null)->groupBy('processor')->pluck('processor','processor');
//        $cities = Work_order::where('city','!=', null)->groupBy('city')->pluck('city','city');
//        $states = Work_order::where('state','!=', null)->groupBy('state')->pluck('state','state');
//        $zip_codes = Work_order::where('zip','!=', null)->groupBy('zip')->pluck('zip','zip');
//        $clients = Client::pluck('name','id');
//        $companies = Company::pluck('name','id');
//        return view('admin.modules.work_order.index', compact(
//            'results',
//            'contractors',
//            'seller',
//            'work_type',
//            'processor',
//            'cities',
//            'states',
//            'zip_codes',
//            'clients',
//            'companies',
//            'summary_row'
//        ));
//    }


    public function search(Request $request)
    {
        $query = Work_order::query();

        if ($request->get('from') !== null) {
            $query->whereDate('receive_date', '>=', $request->input('from'));
        }
        if ($request->get('to') !== null) {
            $query->whereDate('receive_date', '<=', $request->input('to'));
        }

        // Apply other filters
        if ($request->get('company') !== null) {
            $query->where('company_id', $request->input('company'));
        }
        if ($request->get('client') !== null) {
            $query->where('client_id', $request->input('client'));
        }
        if ($request->get('contractor') !== null) {
            $query->where('contractor', $request->input('contractor'));
        }
        if ($request->get('seller') !== null) {
            $query->where('seller', $request->input('seller'));
        }
        if ($request->get('work_type') !== null) {
            $query->where('work_type', $request->input('work_type'));
        }
        if ($request->get('processor') !== null) {
            $query->where('processor', $request->input('processor'));
        }
        if ($request->get('city') !== null) {
            $query->where('city', $request->input('city'));
        }
        if ($request->get('state') !== null) {
            $query->where('state', $request->input('state'));
        }
        if ($request->get('zip') !== null) {
            $query->where('zip', $request->input('zip'));
        }

        if ($request->get('invoice_from') !== null) {
            $query->whereDate('invoice_date', '>=', $request->input('invoice_from'));
        }
        if ($request->get('invoice_to') !== null) {
            $query->whereDate('invoice_date', '<=', $request->input('invoice_to'));
        }

        if ($request->get('ppw_id') !== null || $request->get('work_order_code') !== null) {
            $subQueryMain = Work_order::query();
            $subQuerySub = Work_order::query();

            if ($request->get('ppw_id') !== null) {
                $subQueryMain->where('ppw_id', $request->input('ppw_id'));
                $subQuerySub->where('ppw_id', $request->input('ppw_id'));
            }
            if ($request->get('work_order_code') !== null) {
                $subQueryMain->where('work_order_code', 'LIKE', '%' . $request->input('work_order_code') . '%');
                $subQuerySub->where('work_order_code', 'LIKE', '%' . $request->input('work_order_code') . '%');
            }

            $mainOrders = $subQueryMain->where('main_order_ppw', 0)->pluck('id')->toArray();
            $subOrders = $subQuerySub->where('main_order_ppw', '!=', 0)->pluck('id')->toArray();
            Log::info($mainOrders);
            Log::info($subOrders);

            $query->whereIn('id', array_merge($mainOrders, $subOrders));
        } else {
            $query->where('main_order_ppw', 0);
        }

        // Clone the query to calculate the summary row values without pagination
        $summaryQuery = clone $query;

        // Summary Row;
        $client_total = $summaryQuery->sum('client_amount');
        $vendor_total = $summaryQuery->sum('vendor_amount');
        $client_paid = Bank_statement::where('ppw_id', '!=', null)->where('ppw_amount', '>', 0)->where('account_type', 'Debit')->sum('ppw_amount');
        $client_unpaid = $client_total - $client_paid;
        $total_cashout_debit = abs(Bank_statement::where('ppw_id', '!=', null)->where('ppw_amount', '<', 0)->where('account_type', 'Debit')->sum('ppw_amount'));
        $total_cashout_credit = abs(Bank_statement::where('ppw_id', '!=', null)->where('account_type', 'Credit')->sum('ppw_amount'));
        $total_cashout_loan = 0; // Assuming you get this value from elsewhere if needed
        $vendor_paid = $total_cashout_debit + $total_cashout_credit + $total_cashout_loan;
        $vendor_unpaid = $vendor_total - $vendor_paid;
        $summary_row = [
            'client_total' => $client_total,
            'client_paid' => $client_paid,
            'client_unpaid' => $client_unpaid,
            'paid_from_debit' => $total_cashout_debit,
            'paid_from_credit' => $total_cashout_credit,
            'paid_from_loan' => $total_cashout_loan,
            'vendor_total' => $vendor_total,
            'vendor_paid' => $vendor_paid,
            'vendor_unpaid' => $vendor_unpaid,
            'gross_profit' => $client_total - $vendor_paid,
            'receive_gp' => $client_paid - $vendor_total,
        ];

        $results = $query->orderBy('id', 'desc')->paginate(100);

        $results->each(function ($item) {
            $ppw_id_including_sub_orders = $item->subOrder->pluck('ppw_id')->toArray();
            $ppw_id_including_sub_orders[] = $item->ppw_id;
            $item->client_total = $item->client_amount + $item->subOrder()->sum('client_amount');
            $row_of_client_paid = Bank_statement::whereIn('ppw_id', $ppw_id_including_sub_orders)->where('ppw_amount', '>', 0)->where('account_type', 'Debit');
            if ($row_of_client_paid->count() > 0) {
                $item->total_cash_in = $row_of_client_paid->sum('ppw_amount');
            }
            $item->client_unpaid = $item->client_amount - $item->total_cash_in;
            $item->total_cash_out_from_debit = abs(Bank_statement::whereIn('ppw_id', $ppw_id_including_sub_orders)->where('ppw_amount', '<', 0)->where('account_type', 'Debit')->sum('ppw_amount'));
            $item->total_cash_out_from_credit = abs(Bank_statement::whereIn('ppw_id', $ppw_id_including_sub_orders)->where('account_type', 'Credit')->sum('ppw_amount'));
            $item->profit = $item->total_cash_in - ($item->total_cash_out_from_debit + $item->total_cash_out_from_credit);
            $loan_amount = 0;
            $item->loan_amount = $loan_amount;
            $vendor_total_of_sub_order = Work_order::where('main_order_ppw', $item->ppw_id)->sum('vendor_amount');
            $vendor_total = $item->vendor_amount + $vendor_total_of_sub_order;
            $paid_to_vendor = ($item->total_cash_out_from_debit + $item->total_cash_out_from_credit + $loan_amount);
            $item->vendor_total = $vendor_total;
            $item->vendor_got_paid = $paid_to_vendor;
            $item->vendor_unpaid = $vendor_total - $paid_to_vendor;
            $item->gross_profit = $item->client_amount - $paid_to_vendor;
            if ($row_of_client_paid->count() > 0) {
                $receive_gp = $item->total_cash_in - $vendor_total;
                $item->received_gp = $receive_gp;
            }
        });

        $contractors = Work_order::where('contractor', '!=', null)->groupBy('contractor')->pluck('contractor', 'contractor');
        $seller = Work_order::where('seller', '!=', null)->groupBy('seller')->pluck('seller', 'seller');
        $work_type = Work_order::where('work_type', '!=', null)->groupBy('work_type')->pluck('work_type', 'work_type');
        $processor = Work_order::where('processor', '!=', null)->groupBy('processor')->pluck('processor', 'processor');
        $cities = Work_order::where('city', '!=', null)->groupBy('city')->pluck('city', 'city');
        $states = Work_order::where('state', '!=', null)->groupBy('state')->pluck('state', 'state');
        $zip_codes = Work_order::where('zip', '!=', null)->groupBy('zip')->pluck('zip', 'zip');
        $clients = Client::pluck('name', 'id');
        $companies = Company::pluck('name', 'id');

        return view('admin.modules.work_order.index', compact(
            'results',
            'contractors',
            'seller',
            'work_type',
            'processor',
            'cities',
            'states',
            'zip_codes',
            'clients',
            'companies',
            'summary_row'
        ));
    }





    public function edit($work_order_id){
        $result = Work_order::find($work_order_id);
        $contractors = Work_order::where('contractor','!=', null)->groupBy('contractor')->pluck('contractor','contractor');
        $seller = Work_order::where('seller','!=', null)->groupBy('seller')->pluck('seller','seller');
        $work_type = Work_order::where('work_type','!=', null)->groupBy('work_type')->pluck('work_type','work_type');
        $processor = Work_order::where('processor','!=', null)->groupBy('processor')->pluck('processor','processor');
        $cities = Work_order::where('city','!=', null)->groupBy('city')->pluck('city','city');
        $states = Work_order::where('state','!=', null)->groupBy('state')->pluck('state','state');
        $zip_codes = Work_order::where('zip','!=', null)->groupBy('zip')->pluck('zip','zip');
        $clients = Client::pluck('name','id');
        $companies = Company::pluck('name','id');
        return view('admin.modules.work_order.edit',compact('result','contractors','seller','work_type', 'processor','clients','companies','cities','states','zip_codes'));
    }
    public function update(Request $request, $work_order_id){
        $client_code = Client::find($request->client_id)->code;
        $company_code = Company::find($request->company_id)->code;
        $final_client_code = $company_code + $client_code;
        $workOrderData = [
            'ppw_id' => $request->ppw_id,
            'client' => $final_client_code,
            'client_id' => $request->client_id,
            'company_id' => $request->company_id,
            'company_code' => $company_code,
            'main_order_ppw' => $request->main_order_ppw,
            'receive_date' => $request->receive_date,
            'work_order_code' => $request->work_order_code,
            'contractor' => $request->contractor,
            'work_type' => $request->work_type,
            'address' => $request->address,
            'city' => $request->city,
            'state' => $request->state,
            'zip' => $request->zip,
            'processor' => $request->processor,
            'invoice_date' => $request->invoice_date,
            'seller' => $request->seller,
            'source_ppw' => $request->source_ppw,
            'client_amount' => $request->client_amount,
            'vendor_amount' => $request->vendor_amount,
        ];
        Work_order::find($work_order_id)->fill($workOrderData)->save();
        return redirect('module/work_order')->with('message', 'Work order updated successfully');
    }
}
