<?php

namespace App\Imports;

use App\Models\Employee;
use App\Models\User;
use Carbon\Carbon;
use Illuminate\Support\Arr;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Log;
use Maatwebsite\Excel\Concerns\ToModel;
use Maatwebsite\Excel\Concerns\WithHeadingRow;

class EmployeeImport implements ToModel, WithHeadingRow
{
    private $successCount = 0;
    private $failureCount = 0;
    private $errors = [];

    /**
     * @param array $row
     *
     * @return \Illuminate\Database\Eloquent\Model|null
     */
    public function model(array $row)
    {
        //Log::info($row);
        try {
            // Validate or sanitize $row here if needed
            // Combine the logic into a single updateOrCreate call
            if(!isset($row['first_name']) || is_null($row['first_name'])){
                return null;
            }
            Employee::updateOrCreate(
                [
                    'first_name'     => $row['first_name'],
                    'last_name'      => $row['last_name'],
                ],
                array_filter([
                    'dob'            => $this->parseDate($row['dob']),
                    'class'          => $row['class'],
                    'address'        => $row['address'],
                    'city'           => $row['city'],
                    'state'          => $row['state'],
                    'zip'            => $row['zip'],
                    'dependant'      => $row['dependent'],
                    'apt'            => $row['apt'],
                    'rate_type'      => $row['rate'],
                    'regular_rate'   => $row['regular_rate'],
                    'benefit_rate'   => $row['benefit_rate'],
                ])
            );
            $this->successCount++;
        } catch (\Exception $e) {
            Log::error($e);
            $this->failureCount++;
            $this->errors[] = [
                'row' => $row,
                'error' => $e->getMessage()
            ];
        }
    }

    public function parseDate($date)
    {
        try {
            if (strpos($date, '/') !== false) {
                $date = str_replace('-', '/', $date);
                return Carbon::createFromFormat('m/d/Y', $date)->format('Y-m-d');
            }
            return Carbon::createFromFormat('d/m/Y', $date)->format('Y-m-d');
        } catch (\Exception $e) {
            return null;
        }
    }

    public function getResults()
    {
        return [
            'success_count' => $this->successCount,
            'failure_count' => $this->failureCount,
            'errors' => $this->errors,
        ];
    }

}
