<?php

namespace App\Imports;

use App\Models\Client;
use App\Models\Company;
use App\Models\Work_order;
use Carbon\Carbon;
use Illuminate\Support\Facades\Log;
use Maatwebsite\Excel\Concerns\ToModel;
use Maatwebsite\Excel\Concerns\WithHeadingRow;

class WorkOrderImport implements ToModel, WithHeadingRow
{
    private $successCount = 0;
    private $failureCount = 0;
    private $errors = [];

    public function model(array $row)
    {
        Log::info($row);
        if (isset($row['ppw']) && $row['ppw'] != null) {
            try {
                $converted_date_received = ($row['date_received'] != null ) ? $this->convertDate($row['date_received']) : null;
                $converted_invoice_date = ($row['invoice_date'] != null) ? $this->convertDate($row['invoice_date']) : null;
                $client = $row['client'];
                $client_code = $client % 100;
                $company_code = $client - $client_code;

                $clientModel = Client::where('code', $client_code)->first();
                $companyModel = Company::where('code', $company_code)->first();

                $workOrderData = [
                    'ppw_id' => $row['ppw'],
                    'client' => $client,
                    'main_order_ppw' => $row['main_ppw'] ? $row['main_ppw'] : 0,
                    'client_id' => optional($clientModel)->id,
                    'company_id' => optional($companyModel)->id,
                    'company_code' => $company_code,
                    'receive_date' => $converted_date_received,
                    'work_order_code' => $row['wo'],
                    'contractor' => $row['contractor'],
                    'work_type' => $row['work_type'],
                    'address' => $row['address'],
                    'city' => $row['city'],
                    'state' => $row['state'],
                    'zip' => $row['zip'],
                    'processor' => $row['processor'],
                    'invoice_date' => $converted_invoice_date,
                    'seller' => $row['seller'],
                    'source_ppw' => $row['source_wo'],
                    'client_amount' => $row['client_total'],
                    'vendor_amount' => $row['contractor_total'],
                ];
                Work_order::updateOrCreate(['ppw_id' => $row['ppw']], $workOrderData);
                $this->successCount++;
            } catch (\Exception $e) {
                $this->failureCount++;
                $this->errors[] = [
                    'row' => $row,
                    'error' => $e->getMessage()
                ];
                Log::error('Error during work order data insertion: ' . $e->getMessage());
            }


        }
    }

    private function convertDate($date)
    {
        $formats = [
            'm-d-y', // 11-07-23
            'm/d/Y', // 6/17/2024
            'm/d/y', // 06/07/24
            'm-d-Y'
        ];

        foreach ($formats as $format) {
            try {
                return Carbon::createFromFormat($format, $date)->format('Y-m-d');
            } catch (\Exception $e) {
                continue;
            }
        }

        throw new \Exception("Invalid date format for date: $date");
    }

    public function getResults()
    {
        return [
            'success_count' => $this->successCount,
            'failure_count' => $this->failureCount,
            'errors' => $this->errors,
        ];
    }
}
