@extends('admin.layouts.form')

@section('custom_page_style')
    <style>
        .searchable_dropdown.open .dropdown-menu.inner {
            padding-left: 30px !important;
            margin-left: 10px !important;
        }
        .autoCompleter .bootstrap-autocomplete{
            top:70px!important;
        }

        /* Existing employee highlight (e.g., green border) */
        .existing-employee {
            position: relative;
            border-left: 5px solid #4caf50;
            background-color: #e8f5e9;
            padding-top: 10px;
        }

        /* New employee highlight (e.g., orange border) */
        .new-employee {
            border-left: 5px solid #ff9800;
            position: relative;
            background-color: #fff3e0;
            padding-top: 10px;
        }
        .remove_emp_timesheet_row{
            position: absolute;
            right: 0;
            top: -4px;
            z-index: 1;
        }
        .input-group input[type="text"], .input-group .form-control {
            border: none;
            box-shadow: none;
            padding-left: 5px;
        }

        .bootstrap-select .bs-searchbox, .bootstrap-select .bs-actionsbox, .bootstrap-select .bs-donebutton {
            padding: 0 0 5px 10px;
            border-bottom: 1px solid #e9e9e9;
            margin-left: 37px;
        }

        .icon_of_ad_more_button {
            display: inline-block;
            margin-top: -2px;
            float: left;
            margin-left: 0px;
            margin-right: 4px;
            font-size: 16px !important;
        }

        .loading-overlay {
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background: rgba(0, 0, 0, 0.6);
            z-index: 9999;
            display: flex;  /* Center horizontally */
            align-items: center;  /* Center vertically */
            justify-content: center;  /* Center horizontally */
        }

        .spinner {
            width: 40px;
            height: 40px;
            position: relative;
        }

        .double-bounce1, .double-bounce2 {
            width: 100%;
            height: 100%;
            border-radius: 50%;
            background-color: #fff;
            opacity: 0.6;
            position: absolute;
            top: 0;
            left: 0;
            animation: bounce 2.0s infinite ease-in-out;
        }

        .double-bounce2 {
            animation-delay: -1.0s;
        }

        @keyframes bounce {
            0%, 100% { transform: scale(0.0); }
            50% { transform: scale(1.0); }
        }

        .remove-btn {
            margin-left: 10px;
            margin-top: 4px;
            background-color: red;
        }

        .add-employee-btn {
            width: 100%;
            margin-top: 20px;
        }

        .input-group-addon {
            border-radius: 0;
        }

    </style>
@endsection

@section('content')
    <div class="container-fluid" id="app">
        <div class="block-header clearfix">
            <h2 class="pull-left">
                <i class="material-icons btn btn-sm btn-warning">create</i> <span> &nbsp; Upload new Timesheet</span>
            </h2>
            <a href="{!! URL::to('module/timesheet/uploaded_timesheet_list') !!}" class="pull-right">Back to List</a>
        </div>

        <div class="row clearfix">
            <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
                <div class="card">
                    <div class="body">
                        <div id="loading-overlay" class="loading-overlay" v-show="loading">
                            <div class="spinner">
                                <div class="double-bounce1"></div>
                                <div class="double-bounce2"></div>
                            </div>
                        </div>


                        <div class="row clearfix">
                            <div class="col-xs-12">
                                <label for="timesheet_date">Timesheet Date</label>
                                <div class="input-group">
                                    <span class="input-group-addon">
                                        <i class="material-icons">calendar_today</i>
                                    </span>
                                    <div class="form-line">
                                        {!! Form::text('timesheet_date', null, ['class' => 'form-control datepicker', 'placeholder' => 'Date', 'required', 'v-model'=>'timesheetDate']) !!}
                                    </div>
                                </div>
                                <div v-if="validationErrors.timesheet_date" class="error-message text-danger">
                                    @{{ validationErrors.timesheet_date }}
                                </div>
                            </div>
                        </div>

                        <div class="row clearfix">
                            <div class="col-xs-12">
                                <label for="remarks">Remarks</label>
                                <div class="input-group">
                                    <span class="input-group-addon">
                                        <i class="material-icons">comment</i>
                                    </span>
                                    <div class="form-line">
                                        {!! Form::text('remarks', null, ['class' => 'form-control', 'placeholder' => 'Remarks', 'required', 'v-model'=>'remarks']) !!}
                                    </div>
                                </div>
                                <div v-if="validationErrors.remarks" class="error-message text-danger">
                                    @{{ validationErrors.remarks }}
                                </div>
                            </div>
                        </div>

                        <div class="row clearfix">
                            <div class="col-xs-12">
                                <label for="image_upload">Upload Image</label>
                                <div class="input-group">
                                    <span class="input-group-addon">
                                        <i class="material-icons">image</i>
                                    </span>
                                    <div class="form-line">
                                        <input type="file" id="image_upload" @change="handleImageChange">
                                    </div>
                                </div>
                                <div v-if="validationErrors.image" class="error-message text-danger">
                                    @{{ validationErrors.image }}
                                </div>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-xs-12">
                                <div v-if="uploadFailedError" class="error-message text-danger alert alert-danger">
                                    @{{ uploadFailedError }}
                                </div>
                                <div class="form-group">
                                    <button class="btn btn-success btn-lg btn-block" @click.prevent="uploadImage">Submit Timesheet</button>
                                </div>
                            </div>
                        </div>
                        {!! Form::close() !!}
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection
@section('custom_page_script')
    <script type="text/javascript">
        $(document).ready(function () {
        });

        var app = new Vue({
            el: '#app',
            data: {
                timesheetImage: null,
                timesheetDate: '',
                remarks: '',
                userId: '{!! auth()->user()->id !!}',
                loading: false,
                validationErrors: {},
                uploadFailedError:null
            },
            methods: {
                validateForm() {
                    this.validationErrors = {}; // Reset previous errors
                    if (!this.timesheetImage) this.validationErrors.image = "Image is required.";
                    if (!this.timesheetDate) this.validationErrors.timesheet_date = "Timesheet date is required.";
                    if (!this.remarks) this.validationErrors.remarks = "Remarks are required.";
                    return Object.keys(this.validationErrors).length === 0;
                },
                uploadImage(event) {
                    if (!this.validateForm()) return; // Exit if validation fails

                    const formData = new FormData();
                    formData.append('image', this.timesheetImage);
                    formData.append('timesheet_date', this.timesheetDate);
                    formData.append('remarks', this.remarks);
                    formData.append('user_id', this.userId);

                    this.loading = true;
                    this.uploadFailedError = null
                    axios.post('{!! url(env('IMAGE_PROCESS_API')."/process_timesheet_image") !!}', formData)
                        .then(response => {
                            this.loading = false;
                            if (response.data.success) {
                                alert(response.data.message);
                                window.location.href = "{!! url('module/timesheet/uploaded_timesheet_list') !!}";
                            } else {
                                alert('Failed to upload timesheet');
                            }
                        })
                        .catch(error => {
                            this.loading = false;
                            console.log(error.response.data);
                            this.uploadFailedError = error.response.data.message;
                        });
                },
                handleImageChange(event) {
                    this.timesheetImage = event.target.files[0];
                }
            },
            mounted() {
                const vm = this;
                // Initialize date picker and bind it to Vue data
                $('.datepicker').bootstrapMaterialDatePicker({
                    format: 'MM-DD-YYYY',
                    clearButton: true,
                    weekStart: 1,
                    time: false
                }).on('change', function(e, date) {
                    // Update Vue data when date is selected
                    vm.timesheetDate = date ? date.format('MM-DD-YYYY') : '';
                });
            }
        });
    </script>
@endsection

