@extends('admin.layouts.form')

@section('custom_page_style')
    <style>

    </style>
@endsection

@section('content')
    <div class="container-fluid">
        <!-- Display success message -->
        @if(session('success'))
            <div class="alert alert-success alert-dismissible">
                <button type="button" class="close" data-dismiss="alert">&times;</button>
                <strong>Success!</strong> {{ session('success') }}
            </div>
        @endif
        <div class="block-header clearfix">
            <h2 class="pull-left">
                <i class="material-icons btn btn-sm btn-info">list</i> <span>&nbsp; Uploaded Timesheets</span>
            </h2>
        </div>

        <!-- Search Filter -->
        <form method="GET" action="{{ url('module/timesheet/uploaded_timesheet_list') }}">
            <div class="row clearfix">
                <div class="col-lg-6 col-md-6 col-sm-6 col-xs-12">
                    <div class="input-group">
                        <span class="input-group-addon">
                            <i class="material-icons">person</i>
                        </span>
                        <div class="form-line">
                            {!! Form::text('date', request()->date, ['class' => 'form-control datepicker', 'placeholder' => 'Timesheet date']) !!}
                        </div>
                    </div>
                </div>
                <div class="col-xs-4">
                    {!! Form::submit('SEARCH', ['class'=>'btn btn-md btn-success btn-block']) !!}
                </div>
            </div>
        </form>

        <!-- Timesheet List Table -->
        <div class="row clearfix">
            <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
                <div class="card">
                    <div class="body table-responsive">
                        <table class="table table-hover table-bordered">
                            <thead>
                            <tr>
                                <th>ID</th>
                                <th>Timesheet Date</th>
                                <th>Image</th>
                                <th>Remarks</th>
                                <th>Data process status</th>
                                <th>Uploaded At</th>
                                <th>Actions</th>
                            </tr>
                            </thead>
                            <tbody>
                            @foreach($timesheetImages as $timesheet)
                                <tr>
                                    <td>{{ $timesheet->id }}</td>
                                    <td>{{ $timesheet->timesheet_date }}</td>
                                    <td>
                                        <a target="_blank" data-toggle="tooltip" data-title="Preview" href="{!! $timesheet->image !!}" class="preview-image">
                                            <img src="{!! $timesheet->image !!}" width="50" height="50">
                                        </a>
                                    </td>
                                    <td>{{ $timesheet->remarks }}</td>
                                    <td>
                                        @if($timesheet->verified_by == null)
                                            <span class="badge bg-red">Pending</span>
                                        @else
                                            <span class="badge bg-green">Done</span>
                                        @endif

                                    </td>
                                    <td>{{ $timesheet->created_at->toDateString() }}</td>
                                    <td>
                                        @if(auth()->user()->role_id === 3)
                                            <a href="{!! url('module/timesheet/verify_data_structure', $timesheet->id) !!}" class="btn btn-xs btn-primary">Verify</a>
                                        @endif
                                        @if(auth()->user()->role_id === 2)
                                            <form action="{{ url('module/timesheet/delete_upload_timesheet', $timesheet->id) }}" method="POST" style="display:inline-block;">
                                                @csrf
                                                @method('DELETE')
                                                <button type="submit" class="btn btn-xs btn-danger" data-toggle="tooltip" title="Delete" onclick="return confirm('Are you sure?')"><i class="material-icons">delete</i></button>
                                            </form>
                                        @endif
                                    </td>
                                </tr>
                            @endforeach
                            </tbody>
                        </table>
                        <!-- Pagination -->
                        {{ $timesheetImages->appends(request()->query())->links() }}
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection

@section('custom_page_script')
    <script type="text/javascript">

        $(document).ready(function () {
            $('.datepicker').bootstrapMaterialDatePicker({
                format: 'MM-DD-YYYY',
                clearButton: true,
                weekStart: 1,
                time: false
            }).on('change', function(e, date) {
                // Update Vue data when date is selected
            });

            $('[data-toggle=tooltip]').tooltip();

        });
    </script>
@endsection
