<?php

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

use App\Exports\WorkOrdersExport;
use App\Http\Controllers\Admin;
use App\Http\Controllers\AuthController;
use App\Http\Controllers\BankController;
use App\Http\Controllers\BankStatementController;
use App\Http\Controllers\ClientController;

use App\Http\Controllers\CreditAccountController;
use App\Http\Controllers\EmployeeController;
use App\Http\Controllers\ExpenseHeadController;
use App\Http\Controllers\FacialRekognitionController;
use App\Http\Controllers\ReportController;
use App\Http\Controllers\TimeSheetController;
use App\Http\Controllers\WorkOrderController;
use Maatwebsite\Excel\Facades\Excel;


Route::get('/', [AuthController::class, 'index']);
Route::get('admin', [Admin::class, 'index']);
Route::post('/login',[AuthController::class, 'login']);
Route::get('/logout',[AuthController::class, 'logout']);


Route::group(['prefix'=>'module'],function(){


    Route::resource('client', ClientController::class);


    Route::get('export/work-orders', function (\Illuminate\Http\Request $request) {
        return Excel::download(new WorkOrdersExport($request), 'work_orders.xlsx');
    })->name('export.work_orders');
    Route::any('work_order/search',[WorkOrderController::class, 'search']);
    Route::resource('work_order', WorkOrderController::class);
    Route::resource('bank',BankController::class);
    Route::resource('credit_account', CreditAccountController::class);

    Route::get('statement/create_debit',[BankStatementController::class, 'create_debit']);
    Route::get('statement/create_credit',[BankStatementController::class, 'create_credit']);
    Route::post('bank_statement',[BankStatementController::class, 'store']);
    Route::get('statement',[BankStatementController::class, 'index']);
    Route::get('statement/{id}/edit', [BankStatementController::class, 'edit']);
    Route::patch('bank_statement/{statement_id}',[BankStatementController::class, 'update']);
    Route::any('statement/search',[BankStatementController::class,'search']);

    Route::resource('expense_head', ExpenseHeadController::class);

    Route::any('report/company_wise_report', [ReportController::class, 'companyWiseReport']);
    Route::any('report/expense_report', [ReportController::class, 'expense_report']);


    Route::any('employee/search', [EmployeeController::class, 'index'])->name('employee.search');
    Route::resource('employee', EmployeeController::class);

    Route::get('timesheet/upload_image', [TimeSheetController::class, 'uploadImage']);
    Route::get('timesheet/create', [TimeSheetController::class, 'createTimeSheet']);
    Route::get('timesheet', [TimeSheetController::class, 'index']);
    Route::get('timesheet/timesheet_with_ai', [TimeSheetController::class, 'timeSheetWithAi']);
    Route::post('timesheet/save_ai_generated_timesheet_data/{timesheetImageId}', [TimeSheetController::class, 'saveAiGeneratedTimeSheetData']);
    Route::post('timesheet', [TimeSheetController::class, 'store']);
    Route::post('timesheet/check_employees_by_ssn', [TimeSheetController::class, 'checkEmployeesBySSN']);
    Route::get('timesheet/employee_name_suggestion', [TimeSheetController::class, 'get_employee_suggestions']);

    Route::get('timesheet/upload_timesheet', [TimeSheetController::class, 'getUploadTimesheet']);
    Route::get('timesheet/uploaded_timesheet_list', [TimeSheetController::class, 'getUploadedTimeSheetList']);
    Route::delete('timesheet/delete_upload_timesheet/{id}', [TimeSheetController::class, 'deleteUploadedTimesheet']);

    Route::get('timesheet/verify_data_structure/{timehseetImageId}', [TimeSheetController::class, 'verifyDataStructure']);



    // Attendance module
    Route::get('face_entry', [FacialRekognitionController::class, 'faceEntry']);
    Route::get('face_verification', [FacialRekognitionController::class, 'faceVerification']);




});




